=========
Utilities
=========


Curves
======

.. automodule:: splipy.utils.curve
   :members:


Images
======

.. automodule:: splipy.utils.image
   :members:


Refinement
==========

.. automodule:: splipy.utils.refinement
   :members:


Smoothing
=========

.. automodule:: splipy.utils.smooth
   :members:


Nutils
=========

.. automodule:: splipy.utils.nutils
   :members:
